@@ -6,12 +6,20 @@ use Mojo::File;
 use Music::FretboardDiagram;
 use Imager;
 
+# Usage:
+# http://$host/:chord/:position[?showname={0,Chord+Name}]
+# Examples:
+# http://localhost/002220/1
+# http://localhost/012340/1?showname=0
+# http://localhost/012340/3?showname=Xb+dim
+
 get '/:chord/:position' => sub {
     my $c = shift;
 
     my $dia = Music::FretboardDiagram->new(
         chord    => $c->param('chord'),
         position => $c->param('position'),
+        showname => $c->param('showname') // 1, # query param
         frets    => 6,
         horiz    => 1,
         image    => 1,
