@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.1102';
+our $VERSION = '0.1200';
 
 use Moo;
 use strictures 2;
@@ -83,12 +83,24 @@ has image => (
 );
 
 
-has grid => (
+has string_color => (
     is      => 'ro',
     default => sub { 'blue' },
 );
 
 
+has fret_color => (
+    is      => 'ro',
+    default => sub { 'darkgray' },
+);
+
+
+has dot_color => (
+    is      => 'ro',
+    default => sub { 'black' },
+);
+
+
 has fretboard => (
     is       => 'ro',
     init_arg => undef,
@@ -139,8 +151,7 @@ sub draw {
 
     my $WHITE = 'white';
     my $BLACK = 'black';
-    my $GRAY  = 'gray';
-    my $GRID  = $self->grid;
+    my $TAN   = 'tan';
     my $SPACE = $self->size;
 
     my @chord;
@@ -160,23 +171,10 @@ sub draw {
         warn 'WARNING: Font ', $self->font, " not found\n";
     }
 
-    # Draw the vertical string lines
-    for my $string ( 0 .. $self->strings - 1 ) {
-        $i->line(
-            color => $GRID,
-            x1    => $SPACE + $string * $SPACE,
-            y1    => $SPACE,
-            x2    => $SPACE + $string * $SPACE,
-            y2    => $SPACE + ($self->frets - 1) * $SPACE,
-            aa    => 1,
-            endp  => 1
-        );
-    }
- 
     # Draw the horizontal fret lines
     for my $fret ( 0 .. $self->frets - 1 ) {
         $i->line(
-            color => $GRID,
+            color => $self->fret_color,
             x1    => $SPACE,
             y1    => $SPACE + $fret * $SPACE,
             x2    => $SPACE + ($self->strings - 1) * $SPACE,
@@ -200,7 +198,7 @@ sub draw {
 
         if ( $self->_fret_match($fret) ) {
             $i->circle(
-                color => $GRAY,
+                color => $TAN,
                 r     => $SPACE / 8,
                 x     => $SPACE * $self->strings / 2 + $SPACE / 2,
                 y     => $SPACE + $fret * $SPACE + $SPACE / 2,
@@ -208,6 +206,19 @@ sub draw {
         }
     }
 
+    # Draw the vertical string lines
+    for my $string ( 0 .. $self->strings - 1 ) {
+        $i->line(
+            color => $self->string_color,
+            x1    => $SPACE + $string * $SPACE,
+            y1    => $SPACE,
+            x2    => $SPACE + $string * $SPACE,
+            y2    => $SPACE + ($self->frets - 1) * $SPACE,
+            aa    => 1,
+            endp  => 1
+        );
+    }
+
     # Draw the note/mute markers
     my $string = $self->strings;
 
@@ -248,7 +259,7 @@ sub draw {
             print "Dot at $note,$string = $temp\n" if $self->verbose;
 
             $i->circle(
-                color => $BLACK,
+                color => $self->dot_color,
                 r     => $SPACE / 5,
                 x     => $SPACE + ($self->strings - $string) * $SPACE,
                 y     => $SPACE + $SPACE / 2 + ($note - 1) * $SPACE,
@@ -287,8 +298,7 @@ sub _draw_horiz {
 
     my $WHITE = 'white';
     my $BLACK = 'black';
-    my $GRAY  = 'gray';
-    my $GRID  = $self->grid;
+    my $TAN   = 'tan';
     my $SPACE = $self->size;
 
     my @chord;
@@ -308,23 +318,10 @@ sub _draw_horiz {
         warn 'WARNING: Font ', $self->font, " not found\n";
     }
 
-    # Draw the horizontal string lines
-    for my $string ( 0 .. $self->strings - 1 ) {
-        $i->line(
-            color => $GRID,
-            y1    => $SPACE + $string * $SPACE,
-            x1    => $SPACE,
-            y2    => $SPACE + $string * $SPACE,
-            x2    => $SPACE + ($self->frets - 1) * $SPACE,
-            aa    => 1,
-            endp  => 1
-        );
-    }
- 
     # Draw the vertical fret lines
     for my $fret ( 0 .. $self->frets - 1 ) {
         $i->line(
-            color => $GRID,
+            color => $self->fret_color,
             y1    => $SPACE,
             x1    => $SPACE + $fret * $SPACE,
             y2    => $SPACE + ($self->strings - 1) * $SPACE,
@@ -348,7 +345,7 @@ sub _draw_horiz {
 
         if ( $self->_fret_match($fret) ) {
             $i->circle(
-                color => $GRAY,
+                color => $TAN,
                 r     => $SPACE / 8,
                 y     => $SPACE * $self->strings / 2 + $SPACE / 2,
                 x     => $SPACE + $fret * $SPACE + $SPACE / 2,
@@ -356,6 +353,19 @@ sub _draw_horiz {
         }
     }
 
+    # Draw the horizontal string lines
+    for my $string ( 0 .. $self->strings - 1 ) {
+        $i->line(
+            color => $self->string_color,
+            y1    => $SPACE + $string * $SPACE,
+            x1    => $SPACE,
+            y2    => $SPACE + $string * $SPACE,
+            x2    => $SPACE + ($self->frets - 1) * $SPACE,
+            aa    => 1,
+            endp  => 1
+        );
+    }
+
     # Draw the note/mute markers
     my $string = 1;
 
@@ -396,7 +406,7 @@ sub _draw_horiz {
             print "Dot at fret:$note, string:$string = $temp\n" if $self->verbose;
 
             $i->circle(
-                color => $BLACK,
+                color => $self->dot_color,
                 r     => $SPACE / 5,
                 y     => $SPACE + ($string - 1) * $SPACE,
                 x     => $SPACE + $SPACE / 2 + ($note - 1) * $SPACE,
@@ -485,7 +495,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.1102
+version 0.1200
 
 =head1 SYNOPSIS
 
@@ -515,8 +525,10 @@ version 0.1102
     tuning   => [qw/A E C G/],
     horiz    => 1,
     image    => 1,
-    grid     => 'gray',
     verbose  => 1,
+    string_color => 'blue',
+    fret_color   => 'darkgray',
+    dot_color    => 'gray',
   );
   my $image = $dia->draw;
 
@@ -655,14 +667,30 @@ Return the image from the B<draw> method instead of writing to a file.
 
 Default: 0
 
-=head2 grid
+=head2 string_color
 
-  $grid = $dia->grid;
+  $string_color = $dia->string_color;
 
-The diagram grid (strings and frets) color.
+The diagram string color.
 
 Default: blue
 
+=head2 fret_color
+
+  $fret_color = $dia->fret_color;
+
+The diagram fret color.
+
+Default: darkgray
+
+=head2 dot_color
+
+  $dot_color = $dia->dot_color;
+
+The diagram finger position dot color.
+
+Default: black
+
 =head2 fretboard
 
   $fretboard = $dia->fretboard;
